package experiment;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;

/**
 * 题目：已知集合List<String> listA = new
 * ArrayList<String>();listA中有“1234”，“2456”，“3654
 * ”，“4765”，“5324”，“6098”，“7890”，“1091”，“2670”对象。已知集合List<Integer> listB = new
 * ArrayList
 * <Integer>();listB中有1,2,3,4,5,6,7,1,2对象。现在请：将listA中的对象拆分成单独的数字字符串（也就是将
 * “1234”，拆分成“1”，“2”，“3”，“4”四个对象），并保存在集合listA中②给listA、listB去重②创建新集合List<String>
 * listC = new
 * ArrayList<String>();将listA和listB中相同（字符相同则相同）的对象保存到listC③给集合listC按照倒序排列，然后输出。
 * 
 * @author Burning
 * 
 */
public class ListExer {

	public static void main(String[] args) {

		// 获得listA和listB集合
		List<String> listA = getOneList("1234", "2456", "3654", "4765", "5324",
				"6098", "7890", "1091", "2670");
		List<Integer> listB = getOneList(1, 2, 3, 4, 5, 6, 7, 1, 2);
		printList("listA初始值",listA);
		printList("listB初始值",listB);

		// 将listA中的对象拆分成单独的数字字符串
		listA = reBuildListA(listA);
		printList("将listA中的对象拆分后的值",listA);

		// 去掉集合中相同的对象
		listA = deleteRepeatObject(listA);
		listB = deleteRepeatObject(listB);
		printList("listA去掉重复对象后的值",listA);
		printList("listB去掉重复对象后的值",listB);

		// 将listA和listB中相同（字符相同则相同）的对象保存到listC③给集合listC按照倒序排列
		List<String> listC = getSameObject(listA, listB);

		// 输出listC集合中的值
		 printList("listC中的值",listC);

	}

	/**
	 * 根据传入的参数类型、参数值和个数返回对应的list集合
	 * 
	 * @param objs
	 * @return
	 */
	private static <T> List<T> getOneList(T... objs) {

		List<T> list = new ArrayList<T>();

		for (T t : objs) {
			list.add((T) t);
		}

		return list;
	}

	/**
	 * 将listA中的对象拆分成单独的数字字符串（也就是将 “1234”，拆分成“1”，“2”，“3”，“4”四个对象）
	 * 
	 * @param aList
	 * @return
	 */
	private static List<String> reBuildListA(List<String> aList) {

		List<String> list = new ArrayList<String>();

		for (String s : aList) {
			String[] strs = s.split("");

			for (int i = 1; i < strs.length; i++) {
				list.add(strs[i]);
			}
		}
		return list;
	}

	/**
	 * 去掉list集合中重复的对象
	 * 
	 * @param list
	 * @return
	 */
	private static <T> List<T> deleteRepeatObject(List<T> list) {
		// 因为set集合会自动去掉相同对象，利用下这个特征
		return new ArrayList<T>(new HashSet<T>(list));
	}

	/**
	 * 将listA和listB中相同（字符相同则相同）的对象保存到listC③给集合listC按照倒序排列，然后返回
	 * 
	 * @param listA
	 * @param listB
	 * @return
	 */
	private static List<String> getSameObject(List<String> listA,
			List<Integer> listB) {

		List<String> listC = new ArrayList<String>();

		for (String s : listA) {
			if (listB.contains(Integer.parseInt(s))) {
				listC.add(s);
			}
		}
		Collections.sort(listC);
		Collections.reverse(listC);
		return listC;
	}

	/**
	 * 打印集合
	 * @param <T>
	 * 
	 * @param list
	 */
	private static <T> void printList(String message, List<T> list) {
		
		System.out.println(message + ":" + list);
	}

}
